==> amarok_2.9.0.orig.tar.xz: amarok-2.9.0/tests/context/engines/TestDataEngine.h <==
/****************************************************************************************
* Copyright (c) 2010 Nathan Sala <sala.nathan@gmail.com>                               *
*                                                                                      *
* This program is free software; you can redistribute it and/or modify it under        *
* the terms of the GNU General Public License as published by the Free Software        *
* Foundation; either version 2 of the License, or (at your option) any later           *
* version.                                                                             *
*                                                                                      *
* This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
* PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
*                                                                                      *
* You should have received a copy of the GNU General Public License along with         *
* this program.  If not, see <http://www.gnu.org/licenses/>.                           *
****************************************************************************************/

#ifndef TESTDATAENGINE_H
#define TESTDATAENGINE_H

#include "ContextView.h"

#include <QObject>

class TestDataEngine : public QObject 
{
    public:
        TestDataEngine(QObject* parent = 0);
        
    private:
};

#endif //TESTDATAENGINE_H

==> amarok-2.9.82.tar.xz: amarok-2.9.82/tests/context/engines/TestDataEngine.h <==
/****************************************************************************************
* Copyright (c) 2010 Nathan Sala <sala.nathan@gmail.com>                               *
*                                                                                      *
* This program is free software; you can redistribute it and/or modify it under        *
* the terms of the GNU General Public License as published by the Free Software        *
* Foundation; either version 2 of the License, or (at your option) any later           *
* version.                                                                             *
*                                                                                      *
* This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
* PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
*                                                                                      *
* You should have received a copy of the GNU General Public License along with         *
* this program.  If not, see <http://www.gnu.org/licenses/>.                           *
****************************************************************************************/

#ifndef TESTDATAENGINE_H
#define TESTDATAENGINE_H

#include "ContextView.h"

#include <QObject>

class TestDataEngine : public QObject 
{
    Q_OBJECT

    public:
        TestDataEngine(QObject* parent = nullptr);
        
    private:
};

#endif //TESTDATAENGINE_H
